Method: Google::Cloud::DocumentAI::V1beta3::ImportProcessorVersionRequest#external_processor_version_source

Defined in:
proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb

#external_processor_version_source::Google::Cloud::DocumentAI::V1beta3::ImportProcessorVersionRequest::ExternalProcessorVersionSource

Returns The source processor version to import from. It can be from a different environment and region than the destination processor.

Note: The following fields are mutually exclusive: external_processor_version_source, processor_version_source. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1179

class ImportProcessorVersionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The external source processor version.
  # @!attribute [rw] processor_version
  #   @return [::String]
  #     Required. The processor version name. Format:
  #     `projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}`
  # @!attribute [rw] service_endpoint
  #   @return [::String]
  #     Optional. The Document AI service endpoint. For example,
  #     'https://us-documentai.googleapis.com'
  class ExternalProcessorVersionSource
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end