Class: Google::Cloud::DocumentAI::V1beta3::Dataset
- Inherits:
-
Object
- Object
- Google::Cloud::DocumentAI::V1beta3::Dataset
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/documentai/v1beta3/dataset.rb
Overview
A singleton resource under a Processor which configures a collection of documents.
Defined Under Namespace
Modules: State Classes: DocumentWarehouseConfig, GCSManagedConfig, UnmanagedDatasetConfig
Instance Attribute Summary collapse
-
#document_warehouse_config ⇒ ::Google::Cloud::DocumentAI::V1beta3::Dataset::DocumentWarehouseConfig
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#gcs_managed_config ⇒ ::Google::Cloud::DocumentAI::V1beta3::Dataset::GCSManagedConfig
Optional.
-
#name ⇒ ::String
Dataset resource name.
-
#satisfies_pzi ⇒ ::Boolean
readonly
Output only.
-
#satisfies_pzs ⇒ ::Boolean
readonly
Output only.
-
#state ⇒ ::Google::Cloud::DocumentAI::V1beta3::Dataset::State
Required.
-
#unmanaged_dataset_config ⇒ ::Google::Cloud::DocumentAI::V1beta3::Dataset::UnmanagedDatasetConfig
Optional.
Instance Attribute Details
#document_warehouse_config ⇒ ::Google::Cloud::DocumentAI::V1beta3::Dataset::DocumentWarehouseConfig
This field is deprecated and may be removed in the next major version update.
Returns Optional. Deprecated. Warehouse-based dataset configuration is not supported.
Note: The following fields are mutually exclusive: document_warehouse_config, gcs_managed_config, unmanaged_dataset_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/documentai/v1beta3/dataset.rb', line 62 class Dataset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration specific to the Cloud Storage-based implementation. # @!attribute [rw] gcs_prefix # @return [::Google::Cloud::DocumentAI::V1beta3::GcsPrefix] # Required. The Cloud Storage URI (a directory) where the documents # belonging to the dataset must be stored. class GCSManagedConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to the Document AI Warehouse-based implementation. # @!attribute [r] collection # @return [::String] # Output only. The collection in Document AI Warehouse associated with the # dataset. # @!attribute [r] schema # @return [::String] # Output only. The schema in Document AI Warehouse associated with the # dataset. class DocumentWarehouseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to an unmanaged dataset. class UnmanagedDatasetConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Different states of a dataset. module State # Default unspecified enum, should not be used. STATE_UNSPECIFIED = 0 # Dataset has not been initialized. UNINITIALIZED = 1 # Dataset is being initialized. INITIALIZING = 2 # Dataset has been initialized. INITIALIZED = 3 end end |
#gcs_managed_config ⇒ ::Google::Cloud::DocumentAI::V1beta3::Dataset::GCSManagedConfig
Returns Optional. User-managed Cloud Storage dataset configuration. Use this configuration if the dataset documents are stored under a user-managed Cloud Storage location.
Note: The following fields are mutually exclusive: gcs_managed_config, document_warehouse_config, unmanaged_dataset_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/documentai/v1beta3/dataset.rb', line 62 class Dataset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration specific to the Cloud Storage-based implementation. # @!attribute [rw] gcs_prefix # @return [::Google::Cloud::DocumentAI::V1beta3::GcsPrefix] # Required. The Cloud Storage URI (a directory) where the documents # belonging to the dataset must be stored. class GCSManagedConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to the Document AI Warehouse-based implementation. # @!attribute [r] collection # @return [::String] # Output only. The collection in Document AI Warehouse associated with the # dataset. # @!attribute [r] schema # @return [::String] # Output only. The schema in Document AI Warehouse associated with the # dataset. class DocumentWarehouseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to an unmanaged dataset. class UnmanagedDatasetConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Different states of a dataset. module State # Default unspecified enum, should not be used. STATE_UNSPECIFIED = 0 # Dataset has not been initialized. UNINITIALIZED = 1 # Dataset is being initialized. INITIALIZING = 2 # Dataset has been initialized. INITIALIZED = 3 end end |
#name ⇒ ::String
Returns Dataset resource name.
Format:
projects/{project}/locations/{location}/processors/{processor}/dataset.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/documentai/v1beta3/dataset.rb', line 62 class Dataset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration specific to the Cloud Storage-based implementation. # @!attribute [rw] gcs_prefix # @return [::Google::Cloud::DocumentAI::V1beta3::GcsPrefix] # Required. The Cloud Storage URI (a directory) where the documents # belonging to the dataset must be stored. class GCSManagedConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to the Document AI Warehouse-based implementation. # @!attribute [r] collection # @return [::String] # Output only. The collection in Document AI Warehouse associated with the # dataset. # @!attribute [r] schema # @return [::String] # Output only. The schema in Document AI Warehouse associated with the # dataset. class DocumentWarehouseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to an unmanaged dataset. class UnmanagedDatasetConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Different states of a dataset. module State # Default unspecified enum, should not be used. STATE_UNSPECIFIED = 0 # Dataset has not been initialized. UNINITIALIZED = 1 # Dataset is being initialized. INITIALIZING = 2 # Dataset has been initialized. INITIALIZED = 3 end end |
#satisfies_pzi ⇒ ::Boolean (readonly)
Returns Output only. Reserved for future use.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/documentai/v1beta3/dataset.rb', line 62 class Dataset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration specific to the Cloud Storage-based implementation. # @!attribute [rw] gcs_prefix # @return [::Google::Cloud::DocumentAI::V1beta3::GcsPrefix] # Required. The Cloud Storage URI (a directory) where the documents # belonging to the dataset must be stored. class GCSManagedConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to the Document AI Warehouse-based implementation. # @!attribute [r] collection # @return [::String] # Output only. The collection in Document AI Warehouse associated with the # dataset. # @!attribute [r] schema # @return [::String] # Output only. The schema in Document AI Warehouse associated with the # dataset. class DocumentWarehouseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to an unmanaged dataset. class UnmanagedDatasetConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Different states of a dataset. module State # Default unspecified enum, should not be used. STATE_UNSPECIFIED = 0 # Dataset has not been initialized. UNINITIALIZED = 1 # Dataset is being initialized. INITIALIZING = 2 # Dataset has been initialized. INITIALIZED = 3 end end |
#satisfies_pzs ⇒ ::Boolean (readonly)
Returns Output only. Reserved for future use.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/documentai/v1beta3/dataset.rb', line 62 class Dataset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration specific to the Cloud Storage-based implementation. # @!attribute [rw] gcs_prefix # @return [::Google::Cloud::DocumentAI::V1beta3::GcsPrefix] # Required. The Cloud Storage URI (a directory) where the documents # belonging to the dataset must be stored. class GCSManagedConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to the Document AI Warehouse-based implementation. # @!attribute [r] collection # @return [::String] # Output only. The collection in Document AI Warehouse associated with the # dataset. # @!attribute [r] schema # @return [::String] # Output only. The schema in Document AI Warehouse associated with the # dataset. class DocumentWarehouseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to an unmanaged dataset. class UnmanagedDatasetConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Different states of a dataset. module State # Default unspecified enum, should not be used. STATE_UNSPECIFIED = 0 # Dataset has not been initialized. UNINITIALIZED = 1 # Dataset is being initialized. INITIALIZING = 2 # Dataset has been initialized. INITIALIZED = 3 end end |
#state ⇒ ::Google::Cloud::DocumentAI::V1beta3::Dataset::State
Returns Required. State of the dataset. Ignored when updating dataset.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/documentai/v1beta3/dataset.rb', line 62 class Dataset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration specific to the Cloud Storage-based implementation. # @!attribute [rw] gcs_prefix # @return [::Google::Cloud::DocumentAI::V1beta3::GcsPrefix] # Required. The Cloud Storage URI (a directory) where the documents # belonging to the dataset must be stored. class GCSManagedConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to the Document AI Warehouse-based implementation. # @!attribute [r] collection # @return [::String] # Output only. The collection in Document AI Warehouse associated with the # dataset. # @!attribute [r] schema # @return [::String] # Output only. The schema in Document AI Warehouse associated with the # dataset. class DocumentWarehouseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to an unmanaged dataset. class UnmanagedDatasetConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Different states of a dataset. module State # Default unspecified enum, should not be used. STATE_UNSPECIFIED = 0 # Dataset has not been initialized. UNINITIALIZED = 1 # Dataset is being initialized. INITIALIZING = 2 # Dataset has been initialized. INITIALIZED = 3 end end |
#unmanaged_dataset_config ⇒ ::Google::Cloud::DocumentAI::V1beta3::Dataset::UnmanagedDatasetConfig
Returns Optional. Unmanaged dataset configuration. Use this configuration if the dataset documents are managed by the document service internally (not user-managed).
Note: The following fields are mutually exclusive: unmanaged_dataset_config, gcs_managed_config, document_warehouse_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'proto_docs/google/cloud/documentai/v1beta3/dataset.rb', line 62 class Dataset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration specific to the Cloud Storage-based implementation. # @!attribute [rw] gcs_prefix # @return [::Google::Cloud::DocumentAI::V1beta3::GcsPrefix] # Required. The Cloud Storage URI (a directory) where the documents # belonging to the dataset must be stored. class GCSManagedConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to the Document AI Warehouse-based implementation. # @!attribute [r] collection # @return [::String] # Output only. The collection in Document AI Warehouse associated with the # dataset. # @!attribute [r] schema # @return [::String] # Output only. The schema in Document AI Warehouse associated with the # dataset. class DocumentWarehouseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Configuration specific to an unmanaged dataset. class UnmanagedDatasetConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Different states of a dataset. module State # Default unspecified enum, should not be used. STATE_UNSPECIFIED = 0 # Dataset has not been initialized. UNINITIALIZED = 1 # Dataset is being initialized. INITIALIZING = 2 # Dataset has been initialized. INITIALIZED = 3 end end |