Class: Google::Cloud::DocumentAI::V1beta3::Document::BlobAsset

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/documentai/v1beta3/document.rb

Overview

Represents a blob asset. It's used to store the content of the inline blob in this document, for example, image bytes, such that it can be referenced by other fields in the document via asset ID.

Instance Attribute Summary collapse

Instance Attribute Details

#asset_id::String

Returns Optional. The id of the blob asset.

Returns:

  • (::String)

    Optional. The id of the blob asset.



1460
1461
1462
1463
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1460

class BlobAsset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#content::String

Returns Optional. The content of the blob asset, for example, image bytes.

Returns:

  • (::String)

    Optional. The content of the blob asset, for example, image bytes.



1460
1461
1462
1463
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1460

class BlobAsset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#mime_type::String

Returns The mime type of the blob asset. An IANA published media type (MIME type).

Returns:



1460
1461
1462
1463
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1460

class BlobAsset
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end