Class: Google::Cloud::DocumentAI::V1beta3::Document::EntityValidationOutput

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/documentai/v1beta3/document.rb

Overview

The output of the validation given the document and the validation rules.

Defined Under Namespace

Classes: ValidationResult

Instance Attribute Summary collapse

Instance Attribute Details

#pass_all_rules::Boolean

Returns The overall result of the validation, true if all applicable rules are valid.

Returns:

  • (::Boolean)

    The overall result of the validation, true if all applicable rules are valid.



1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1473

class EntityValidationOutput
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Validation result for a single validation rule.
  # @!attribute [rw] rule_name
  #   @return [::String]
  #     The display name of the validation rule.
  # @!attribute [rw] rule_description
  #   @return [::String]
  #     The description of the validation rule.
  # @!attribute [rw] validation_result_type
  #   @return [::Google::Cloud::DocumentAI::V1beta3::Document::EntityValidationOutput::ValidationResult::ValidationResultType]
  #     The result of the validation rule.
  # @!attribute [rw] validation_details
  #   @return [::String]
  #     The detailed information of the running the validation process using
  #     the entity from the document based on the validation rule.
  class ValidationResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The result of the validation rule.
    module ValidationResultType
      # The validation result type is unspecified.
      VALIDATION_RESULT_TYPE_UNSPECIFIED = 0

      # The validation is valid.
      VALIDATION_RESULT_TYPE_VALID = 1

      # The validation is invalid.
      VALIDATION_RESULT_TYPE_INVALID = 2

      # The validation is skipped.
      VALIDATION_RESULT_TYPE_SKIPPED = 3

      # The validation is not applicable.
      VALIDATION_RESULT_TYPE_NOT_APPLICABLE = 4
    end
  end
end

#validation_results::Array<::Google::Cloud::DocumentAI::V1beta3::Document::EntityValidationOutput::ValidationResult>

Returns The result of each validation rule.

Returns:



1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1473

class EntityValidationOutput
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Validation result for a single validation rule.
  # @!attribute [rw] rule_name
  #   @return [::String]
  #     The display name of the validation rule.
  # @!attribute [rw] rule_description
  #   @return [::String]
  #     The description of the validation rule.
  # @!attribute [rw] validation_result_type
  #   @return [::Google::Cloud::DocumentAI::V1beta3::Document::EntityValidationOutput::ValidationResult::ValidationResultType]
  #     The result of the validation rule.
  # @!attribute [rw] validation_details
  #   @return [::String]
  #     The detailed information of the running the validation process using
  #     the entity from the document based on the validation rule.
  class ValidationResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The result of the validation rule.
    module ValidationResultType
      # The validation result type is unspecified.
      VALIDATION_RESULT_TYPE_UNSPECIFIED = 0

      # The validation is valid.
      VALIDATION_RESULT_TYPE_VALID = 1

      # The validation is invalid.
      VALIDATION_RESULT_TYPE_INVALID = 2

      # The validation is skipped.
      VALIDATION_RESULT_TYPE_SKIPPED = 3

      # The validation is not applicable.
      VALIDATION_RESULT_TYPE_NOT_APPLICABLE = 4
    end
  end
end