Class: Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/documentai/v1beta3/document.rb

Overview

Visual element describing a layout unit on a page.

Defined Under Namespace

Modules: Orientation

Instance Attribute Summary collapse

Instance Attribute Details

#bounding_poly::Google::Cloud::DocumentAI::V1beta3::BoundingPoly

Returns The bounding polygon for the Layout.

Returns:



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 337

class Layout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Detected human reading orientation.
  module Orientation
    # Unspecified orientation.
    ORIENTATION_UNSPECIFIED = 0

    # Orientation is aligned with page up.
    PAGE_UP = 1

    # Orientation is aligned with page right.
    # Turn the head 90 degrees clockwise from upright to read.
    PAGE_RIGHT = 2

    # Orientation is aligned with page down.
    # Turn the head 180 degrees from upright to read.
    PAGE_DOWN = 3

    # Orientation is aligned with page left.
    # Turn the head 90 degrees counterclockwise from upright to read.
    PAGE_LEFT = 4
  end
end

#confidence::Float

Returns Confidence of the current Layout within context of the object this layout is for. For example, confidence can be for a single token, a table, a visual element, etc. depending on context. Range [0, 1].

Returns:

  • (::Float)

    Confidence of the current Layout within context of the object this layout is for. For example, confidence can be for a single token, a table, a visual element, etc. depending on context. Range [0, 1].



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 337

class Layout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Detected human reading orientation.
  module Orientation
    # Unspecified orientation.
    ORIENTATION_UNSPECIFIED = 0

    # Orientation is aligned with page up.
    PAGE_UP = 1

    # Orientation is aligned with page right.
    # Turn the head 90 degrees clockwise from upright to read.
    PAGE_RIGHT = 2

    # Orientation is aligned with page down.
    # Turn the head 180 degrees from upright to read.
    PAGE_DOWN = 3

    # Orientation is aligned with page left.
    # Turn the head 90 degrees counterclockwise from upright to read.
    PAGE_LEFT = 4
  end
end

#orientation::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout::Orientation

Returns Detected orientation for the Layout.



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 337

class Layout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Detected human reading orientation.
  module Orientation
    # Unspecified orientation.
    ORIENTATION_UNSPECIFIED = 0

    # Orientation is aligned with page up.
    PAGE_UP = 1

    # Orientation is aligned with page right.
    # Turn the head 90 degrees clockwise from upright to read.
    PAGE_RIGHT = 2

    # Orientation is aligned with page down.
    # Turn the head 180 degrees from upright to read.
    PAGE_DOWN = 3

    # Orientation is aligned with page left.
    # Turn the head 90 degrees counterclockwise from upright to read.
    PAGE_LEFT = 4
  end
end

#text_anchor::Google::Cloud::DocumentAI::V1beta3::Document::TextAnchor

Returns Text anchor indexing into the Document.text.

Returns:



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 337

class Layout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Detected human reading orientation.
  module Orientation
    # Unspecified orientation.
    ORIENTATION_UNSPECIFIED = 0

    # Orientation is aligned with page up.
    PAGE_UP = 1

    # Orientation is aligned with page right.
    # Turn the head 90 degrees clockwise from upright to read.
    PAGE_RIGHT = 2

    # Orientation is aligned with page down.
    # Turn the head 180 degrees from upright to read.
    PAGE_DOWN = 3

    # Orientation is aligned with page left.
    # Turn the head 90 degrees counterclockwise from upright to read.
    PAGE_LEFT = 4
  end
end