Class: Google::Cloud::DocumentAI::V1beta3::Document::Page::Table
- Inherits:
-
Object
- Object
- Google::Cloud::DocumentAI::V1beta3::Document::Page::Table
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/documentai/v1beta3/document.rb
Overview
A table representation similar to HTML table structure.
Defined Under Namespace
Instance Attribute Summary collapse
-
#body_rows ⇒ ::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableRow>
Body rows of the table.
-
#detected_languages ⇒ ::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::DetectedLanguage>
A list of detected languages together with confidence.
-
#header_rows ⇒ ::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableRow>
Header rows of the table.
- #layout ⇒ ::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout
-
#provenance ⇒ ::Google::Cloud::DocumentAI::V1beta3::Document::Provenance
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#body_rows ⇒ ::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableRow>
Returns Body rows of the table.
570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 570 class Table include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A row of table cells. # @!attribute [rw] cells # @return [::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableCell>] # Cells that make up this row. class TableRow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A cell representation inside the table. # @!attribute [rw] layout # @return [::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout] # {::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout Layout} for # {::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableCell TableCell}. # @!attribute [rw] row_span # @return [::Integer] # How many rows this cell spans. # @!attribute [rw] col_span # @return [::Integer] # How many columns this cell spans. # @!attribute [rw] detected_languages # @return [::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::DetectedLanguage>] # A list of detected languages together with confidence. class TableCell include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#detected_languages ⇒ ::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::DetectedLanguage>
Returns A list of detected languages together with confidence.
570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 570 class Table include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A row of table cells. # @!attribute [rw] cells # @return [::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableCell>] # Cells that make up this row. class TableRow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A cell representation inside the table. # @!attribute [rw] layout # @return [::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout] # {::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout Layout} for # {::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableCell TableCell}. # @!attribute [rw] row_span # @return [::Integer] # How many rows this cell spans. # @!attribute [rw] col_span # @return [::Integer] # How many columns this cell spans. # @!attribute [rw] detected_languages # @return [::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::DetectedLanguage>] # A list of detected languages together with confidence. class TableCell include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#header_rows ⇒ ::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableRow>
Returns Header rows of the table.
570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 570 class Table include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A row of table cells. # @!attribute [rw] cells # @return [::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableCell>] # Cells that make up this row. class TableRow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A cell representation inside the table. # @!attribute [rw] layout # @return [::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout] # {::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout Layout} for # {::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableCell TableCell}. # @!attribute [rw] row_span # @return [::Integer] # How many rows this cell spans. # @!attribute [rw] col_span # @return [::Integer] # How many columns this cell spans. # @!attribute [rw] detected_languages # @return [::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::DetectedLanguage>] # A list of detected languages together with confidence. class TableCell include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#layout ⇒ ::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout
570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 570 class Table include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A row of table cells. # @!attribute [rw] cells # @return [::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableCell>] # Cells that make up this row. class TableRow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A cell representation inside the table. # @!attribute [rw] layout # @return [::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout] # {::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout Layout} for # {::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableCell TableCell}. # @!attribute [rw] row_span # @return [::Integer] # How many rows this cell spans. # @!attribute [rw] col_span # @return [::Integer] # How many columns this cell spans. # @!attribute [rw] detected_languages # @return [::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::DetectedLanguage>] # A list of detected languages together with confidence. class TableCell include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#provenance ⇒ ::Google::Cloud::DocumentAI::V1beta3::Document::Provenance
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns The history of this table.
570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 570 class Table include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A row of table cells. # @!attribute [rw] cells # @return [::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableCell>] # Cells that make up this row. class TableRow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A cell representation inside the table. # @!attribute [rw] layout # @return [::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout] # {::Google::Cloud::DocumentAI::V1beta3::Document::Page::Layout Layout} for # {::Google::Cloud::DocumentAI::V1beta3::Document::Page::Table::TableCell TableCell}. # @!attribute [rw] row_span # @return [::Integer] # How many rows this cell spans. # @!attribute [rw] col_span # @return [::Integer] # How many columns this cell spans. # @!attribute [rw] detected_languages # @return [::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Page::DetectedLanguage>] # A list of detected languages together with confidence. class TableCell include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |