Class: Google::Cloud::DocumentAI::V1beta3::Document::Provenance

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/documentai/v1beta3/document.rb

Overview

Structure to identify provenance relationships between annotations in different revisions.

Defined Under Namespace

Modules: OperationType Classes: Parent

Instance Attribute Summary collapse

Instance Attribute Details

#id::Integer

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns The Id of this operation. Needs to be unique within the scope of the revision.

Returns:

  • (::Integer)

    The Id of this operation. Needs to be unique within the scope of the revision.



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 998

class Provenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The parent element the current element is based on. Used for
  # referencing/aligning, removal and replacement operations.
  # @!attribute [rw] revision
  #   @return [::Integer]
  #     The index of the index into current revision's parent_ids list.
  # @!attribute [rw] index
  #   @return [::Integer]
  #     The index of the parent item in the corresponding item list (eg. list
  #     of entities, properties within entities, etc.) in the parent revision.
  # @!attribute [rw] id
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::Integer]
  #     The id of the parent provenance.
  class Parent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # If a processor or agent does an explicit operation on existing elements.
  module OperationType
    # Operation type unspecified. If no operation is specified a provenance
    # entry is simply used to match against a `parent`.
    OPERATION_TYPE_UNSPECIFIED = 0

    # Add an element.
    ADD = 1

    # Remove an element identified by `parent`.
    REMOVE = 2

    # Updates any fields within the given provenance scope of the message. It
    # overwrites the fields rather than replacing them.  Use this when you
    # want to update a field value of an entity without also updating all the
    # child properties.
    UPDATE = 7

    # Currently unused. Replace an element identified by `parent`.
    REPLACE = 3

    # Deprecated. Request human review for the element identified by
    # `parent`.
    EVAL_REQUESTED = 4

    # Deprecated. Element is reviewed and approved at human review,
    # confidence will be set to 1.0.
    EVAL_APPROVED = 5

    # Deprecated. Element is skipped in the validation process.
    EVAL_SKIPPED = 6
  end
end

#parents::Array<::Google::Cloud::DocumentAI::V1beta3::Document::Provenance::Parent>

Returns References to the original elements that are replaced.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 998

class Provenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The parent element the current element is based on. Used for
  # referencing/aligning, removal and replacement operations.
  # @!attribute [rw] revision
  #   @return [::Integer]
  #     The index of the index into current revision's parent_ids list.
  # @!attribute [rw] index
  #   @return [::Integer]
  #     The index of the parent item in the corresponding item list (eg. list
  #     of entities, properties within entities, etc.) in the parent revision.
  # @!attribute [rw] id
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::Integer]
  #     The id of the parent provenance.
  class Parent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # If a processor or agent does an explicit operation on existing elements.
  module OperationType
    # Operation type unspecified. If no operation is specified a provenance
    # entry is simply used to match against a `parent`.
    OPERATION_TYPE_UNSPECIFIED = 0

    # Add an element.
    ADD = 1

    # Remove an element identified by `parent`.
    REMOVE = 2

    # Updates any fields within the given provenance scope of the message. It
    # overwrites the fields rather than replacing them.  Use this when you
    # want to update a field value of an entity without also updating all the
    # child properties.
    UPDATE = 7

    # Currently unused. Replace an element identified by `parent`.
    REPLACE = 3

    # Deprecated. Request human review for the element identified by
    # `parent`.
    EVAL_REQUESTED = 4

    # Deprecated. Element is reviewed and approved at human review,
    # confidence will be set to 1.0.
    EVAL_APPROVED = 5

    # Deprecated. Element is skipped in the validation process.
    EVAL_SKIPPED = 6
  end
end

#revision::Integer

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns The index of the revision that produced this element.

Returns:

  • (::Integer)

    The index of the revision that produced this element.



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 998

class Provenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The parent element the current element is based on. Used for
  # referencing/aligning, removal and replacement operations.
  # @!attribute [rw] revision
  #   @return [::Integer]
  #     The index of the index into current revision's parent_ids list.
  # @!attribute [rw] index
  #   @return [::Integer]
  #     The index of the parent item in the corresponding item list (eg. list
  #     of entities, properties within entities, etc.) in the parent revision.
  # @!attribute [rw] id
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::Integer]
  #     The id of the parent provenance.
  class Parent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # If a processor or agent does an explicit operation on existing elements.
  module OperationType
    # Operation type unspecified. If no operation is specified a provenance
    # entry is simply used to match against a `parent`.
    OPERATION_TYPE_UNSPECIFIED = 0

    # Add an element.
    ADD = 1

    # Remove an element identified by `parent`.
    REMOVE = 2

    # Updates any fields within the given provenance scope of the message. It
    # overwrites the fields rather than replacing them.  Use this when you
    # want to update a field value of an entity without also updating all the
    # child properties.
    UPDATE = 7

    # Currently unused. Replace an element identified by `parent`.
    REPLACE = 3

    # Deprecated. Request human review for the element identified by
    # `parent`.
    EVAL_REQUESTED = 4

    # Deprecated. Element is reviewed and approved at human review,
    # confidence will be set to 1.0.
    EVAL_APPROVED = 5

    # Deprecated. Element is skipped in the validation process.
    EVAL_SKIPPED = 6
  end
end

#type::Google::Cloud::DocumentAI::V1beta3::Document::Provenance::OperationType

Returns The type of provenance operation.

Returns:



998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 998

class Provenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The parent element the current element is based on. Used for
  # referencing/aligning, removal and replacement operations.
  # @!attribute [rw] revision
  #   @return [::Integer]
  #     The index of the index into current revision's parent_ids list.
  # @!attribute [rw] index
  #   @return [::Integer]
  #     The index of the parent item in the corresponding item list (eg. list
  #     of entities, properties within entities, etc.) in the parent revision.
  # @!attribute [rw] id
  #   @deprecated This field is deprecated and may be removed in the next major version update.
  #   @return [::Integer]
  #     The id of the parent provenance.
  class Parent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # If a processor or agent does an explicit operation on existing elements.
  module OperationType
    # Operation type unspecified. If no operation is specified a provenance
    # entry is simply used to match against a `parent`.
    OPERATION_TYPE_UNSPECIFIED = 0

    # Add an element.
    ADD = 1

    # Remove an element identified by `parent`.
    REMOVE = 2

    # Updates any fields within the given provenance scope of the message. It
    # overwrites the fields rather than replacing them.  Use this when you
    # want to update a field value of an entity without also updating all the
    # child properties.
    UPDATE = 7

    # Currently unused. Replace an element identified by `parent`.
    REPLACE = 3

    # Deprecated. Request human review for the element identified by
    # `parent`.
    EVAL_REQUESTED = 4

    # Deprecated. Element is reviewed and approved at human review,
    # confidence will be set to 1.0.
    EVAL_APPROVED = 5

    # Deprecated. Element is skipped in the validation process.
    EVAL_SKIPPED = 6
  end
end