Class: Google::Cloud::DocumentAI::V1beta3::Document::TextAnchor
- Inherits:
-
Object
- Object
- Google::Cloud::DocumentAI::V1beta3::Document::TextAnchor
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/documentai/v1beta3/document.rb
Overview
Text reference indexing into the Document.text.
Defined Under Namespace
Classes: TextSegment
Instance Attribute Summary collapse
-
#content ⇒ ::String
Contains the content of the text span so that users do not have to look it up in the text_segments.
-
#text_segments ⇒ ::Array<::Google::Cloud::DocumentAI::V1beta3::Document::TextAnchor::TextSegment>
The text segments from the Document.text.
Instance Attribute Details
#content ⇒ ::String
Returns Contains the content of the text span so that users do not have to look it up in the text_segments. It is always populated for formFields.
870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 870 class TextAnchor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A text segment in the # {::Google::Cloud::DocumentAI::V1beta3::Document#text Document.text}. The # indices may be out of bounds which indicate that the text extends into # another document shard for large sharded documents. See # {::Google::Cloud::DocumentAI::V1beta3::Document::ShardInfo#text_offset ShardInfo.text_offset} # @!attribute [rw] start_index # @return [::Integer] # {::Google::Cloud::DocumentAI::V1beta3::Document::TextAnchor::TextSegment TextSegment} # start UTF-8 char index in the # {::Google::Cloud::DocumentAI::V1beta3::Document#text Document.text}. # @!attribute [rw] end_index # @return [::Integer] # {::Google::Cloud::DocumentAI::V1beta3::Document::TextAnchor::TextSegment TextSegment} # half open end UTF-8 char index in the # {::Google::Cloud::DocumentAI::V1beta3::Document#text Document.text}. class TextSegment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#text_segments ⇒ ::Array<::Google::Cloud::DocumentAI::V1beta3::Document::TextAnchor::TextSegment>
Returns The text segments from the Document.text.
870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 870 class TextAnchor include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A text segment in the # {::Google::Cloud::DocumentAI::V1beta3::Document#text Document.text}. The # indices may be out of bounds which indicate that the text extends into # another document shard for large sharded documents. See # {::Google::Cloud::DocumentAI::V1beta3::Document::ShardInfo#text_offset ShardInfo.text_offset} # @!attribute [rw] start_index # @return [::Integer] # {::Google::Cloud::DocumentAI::V1beta3::Document::TextAnchor::TextSegment TextSegment} # start UTF-8 char index in the # {::Google::Cloud::DocumentAI::V1beta3::Document#text Document.text}. # @!attribute [rw] end_index # @return [::Integer] # {::Google::Cloud::DocumentAI::V1beta3::Document::TextAnchor::TextSegment TextSegment} # half open end UTF-8 char index in the # {::Google::Cloud::DocumentAI::V1beta3::Document#text Document.text}. class TextSegment include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |