Class: Google::Cloud::DocumentAI::V1beta3::DocumentOutputConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/documentai/v1beta3/document_io.rb

Overview

Config that controls the output of documents. All documents will be written as a JSON file.

Defined Under Namespace

Classes: GcsOutputConfig

Instance Attribute Summary collapse

Instance Attribute Details

#gcs_output_config::Google::Cloud::DocumentAI::V1beta3::DocumentOutputConfig::GcsOutputConfig

Returns Output config to write the results to Cloud Storage.

Returns:



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'proto_docs/google/cloud/documentai/v1beta3/document_io.rb', line 113

class DocumentOutputConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The configuration used when outputting documents.
  # @!attribute [rw] gcs_uri
  #   @return [::String]
  #     The Cloud Storage uri (a directory) of the output.
  # @!attribute [rw] field_mask
  #   @return [::Google::Protobuf::FieldMask]
  #     Specifies which fields to include in the output documents.
  #     Only supports top level document and pages field so it must be in the
  #     form of `{document_field_name}` or `pages.{page_field_name}`.
  # @!attribute [rw] sharding_config
  #   @return [::Google::Cloud::DocumentAI::V1beta3::DocumentOutputConfig::GcsOutputConfig::ShardingConfig]
  #     Specifies the sharding config for the output document.
  class GcsOutputConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # The sharding config for the output document.
    # @!attribute [rw] pages_per_shard
    #   @return [::Integer]
    #     The number of pages per shard.
    # @!attribute [rw] pages_overlap
    #   @return [::Integer]
    #     The number of overlapping pages between consecutive shards.
    class ShardingConfig
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end