Class: Google::Cloud::DocumentAI::V1beta3::DocumentOutputConfig::GcsOutputConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/documentai/v1beta3/document_io.rb

Overview

The configuration used when outputting documents.

Defined Under Namespace

Classes: ShardingConfig

Instance Attribute Summary collapse

Instance Attribute Details

#field_mask::Google::Protobuf::FieldMask

Returns Specifies which fields to include in the output documents. Only supports top level document and pages field so it must be in the form of {document_field_name} or pages.{page_field_name}.

Returns:

  • (::Google::Protobuf::FieldMask)

    Specifies which fields to include in the output documents. Only supports top level document and pages field so it must be in the form of {document_field_name} or pages.{page_field_name}.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/documentai/v1beta3/document_io.rb', line 129

class GcsOutputConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The sharding config for the output document.
  # @!attribute [rw] pages_per_shard
  #   @return [::Integer]
  #     The number of pages per shard.
  # @!attribute [rw] pages_overlap
  #   @return [::Integer]
  #     The number of overlapping pages between consecutive shards.
  class ShardingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#gcs_uri::String

Returns The Cloud Storage uri (a directory) of the output.

Returns:

  • (::String)

    The Cloud Storage uri (a directory) of the output.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/documentai/v1beta3/document_io.rb', line 129

class GcsOutputConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The sharding config for the output document.
  # @!attribute [rw] pages_per_shard
  #   @return [::Integer]
  #     The number of pages per shard.
  # @!attribute [rw] pages_overlap
  #   @return [::Integer]
  #     The number of overlapping pages between consecutive shards.
  class ShardingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#sharding_config::Google::Cloud::DocumentAI::V1beta3::DocumentOutputConfig::GcsOutputConfig::ShardingConfig

Returns Specifies the sharding config for the output document.

Returns:



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'proto_docs/google/cloud/documentai/v1beta3/document_io.rb', line 129

class GcsOutputConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The sharding config for the output document.
  # @!attribute [rw] pages_per_shard
  #   @return [::Integer]
  #     The number of pages per shard.
  # @!attribute [rw] pages_overlap
  #   @return [::Integer]
  #     The number of overlapping pages between consecutive shards.
  class ShardingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end