Class: Google::Cloud::DocumentAI::V1beta3::Evaluation::Metrics

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/documentai/v1beta3/evaluation.rb

Overview

Evaluation metrics, either in aggregate or about a specific entity.

Instance Attribute Summary collapse

Instance Attribute Details

#f1_score::Float

Returns The calculated F1 score.

Returns:

  • (::Float)

    The calculated F1 score.



127
128
129
130
# File 'proto_docs/google/cloud/documentai/v1beta3/evaluation.rb', line 127

class Metrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#false_negatives_count::Integer

Returns The amount of false negatives.

Returns:

  • (::Integer)

    The amount of false negatives.



127
128
129
130
# File 'proto_docs/google/cloud/documentai/v1beta3/evaluation.rb', line 127

class Metrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#false_positives_count::Integer

Returns The amount of false positives.

Returns:

  • (::Integer)

    The amount of false positives.



127
128
129
130
# File 'proto_docs/google/cloud/documentai/v1beta3/evaluation.rb', line 127

class Metrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ground_truth_document_count::Integer

Returns The amount of documents with a ground truth occurrence.

Returns:

  • (::Integer)

    The amount of documents with a ground truth occurrence.



127
128
129
130
# File 'proto_docs/google/cloud/documentai/v1beta3/evaluation.rb', line 127

class Metrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ground_truth_occurrences_count::Integer

Returns The amount of occurrences in ground truth documents.

Returns:

  • (::Integer)

    The amount of occurrences in ground truth documents.



127
128
129
130
# File 'proto_docs/google/cloud/documentai/v1beta3/evaluation.rb', line 127

class Metrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#precision::Float

Returns The calculated precision.

Returns:

  • (::Float)

    The calculated precision.



127
128
129
130
# File 'proto_docs/google/cloud/documentai/v1beta3/evaluation.rb', line 127

class Metrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#predicted_document_count::Integer

Returns The amount of documents with a predicted occurrence.

Returns:

  • (::Integer)

    The amount of documents with a predicted occurrence.



127
128
129
130
# File 'proto_docs/google/cloud/documentai/v1beta3/evaluation.rb', line 127

class Metrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#predicted_occurrences_count::Integer

Returns The amount of occurrences in predicted documents.

Returns:

  • (::Integer)

    The amount of occurrences in predicted documents.



127
128
129
130
# File 'proto_docs/google/cloud/documentai/v1beta3/evaluation.rb', line 127

class Metrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#recall::Float

Returns The calculated recall.

Returns:

  • (::Float)

    The calculated recall.



127
128
129
130
# File 'proto_docs/google/cloud/documentai/v1beta3/evaluation.rb', line 127

class Metrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_documents_count::Integer

Returns The amount of documents that had an occurrence of this label.

Returns:

  • (::Integer)

    The amount of documents that had an occurrence of this label.



127
128
129
130
# File 'proto_docs/google/cloud/documentai/v1beta3/evaluation.rb', line 127

class Metrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#true_positives_count::Integer

Returns The amount of true positives.

Returns:

  • (::Integer)

    The amount of true positives.



127
128
129
130
# File 'proto_docs/google/cloud/documentai/v1beta3/evaluation.rb', line 127

class Metrics
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end