Class: Google::Cloud::DocumentAI::V1beta3::ProcessOptions::LayoutConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb

Overview

Serving config for layout parser processor.

Defined Under Namespace

Classes: ChunkingConfig

Instance Attribute Summary collapse

Instance Attribute Details

#chunking_config::Google::Cloud::DocumentAI::V1beta3::ProcessOptions::LayoutConfig::ChunkingConfig



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 74

class LayoutConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Serving config for chunking.
  # @!attribute [rw] chunk_size
  #   @return [::Integer]
  #     Optional. The chunk sizes to use when splitting documents, in order of
  #     level.
  # @!attribute [rw] include_ancestor_headings
  #   @return [::Boolean]
  #     Optional. Whether or not to include ancestor headings when splitting.
  # @!attribute [rw] semantic_chunking_group_size
  #   @return [::Boolean]
  #     Optional. The number of tokens to group together when evaluating
  #     semantic similarity. THIS FIELD IS NOT YET USED.
  # @!attribute [rw] breakpoint_percentile_threshold
  #   @return [::Integer]
  #     Optional. The percentile of cosine dissimilarity that must be exceeded
  #     between a group of tokens and the next. The smaller this number is, the
  #     more chunks will be generated. THIS FIELD IS NOT YET USED.
  class ChunkingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#enable_llm_layout_parsing::Boolean



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 74

class LayoutConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Serving config for chunking.
  # @!attribute [rw] chunk_size
  #   @return [::Integer]
  #     Optional. The chunk sizes to use when splitting documents, in order of
  #     level.
  # @!attribute [rw] include_ancestor_headings
  #   @return [::Boolean]
  #     Optional. Whether or not to include ancestor headings when splitting.
  # @!attribute [rw] semantic_chunking_group_size
  #   @return [::Boolean]
  #     Optional. The number of tokens to group together when evaluating
  #     semantic similarity. THIS FIELD IS NOT YET USED.
  # @!attribute [rw] breakpoint_percentile_threshold
  #   @return [::Integer]
  #     Optional. The percentile of cosine dissimilarity that must be exceeded
  #     between a group of tokens and the next. The smaller this number is, the
  #     more chunks will be generated. THIS FIELD IS NOT YET USED.
  class ChunkingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#return_bounding_boxes::Boolean



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 74

class LayoutConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Serving config for chunking.
  # @!attribute [rw] chunk_size
  #   @return [::Integer]
  #     Optional. The chunk sizes to use when splitting documents, in order of
  #     level.
  # @!attribute [rw] include_ancestor_headings
  #   @return [::Boolean]
  #     Optional. Whether or not to include ancestor headings when splitting.
  # @!attribute [rw] semantic_chunking_group_size
  #   @return [::Boolean]
  #     Optional. The number of tokens to group together when evaluating
  #     semantic similarity. THIS FIELD IS NOT YET USED.
  # @!attribute [rw] breakpoint_percentile_threshold
  #   @return [::Integer]
  #     Optional. The percentile of cosine dissimilarity that must be exceeded
  #     between a group of tokens and the next. The smaller this number is, the
  #     more chunks will be generated. THIS FIELD IS NOT YET USED.
  class ChunkingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#return_images::Boolean



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 74

class LayoutConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Serving config for chunking.
  # @!attribute [rw] chunk_size
  #   @return [::Integer]
  #     Optional. The chunk sizes to use when splitting documents, in order of
  #     level.
  # @!attribute [rw] include_ancestor_headings
  #   @return [::Boolean]
  #     Optional. Whether or not to include ancestor headings when splitting.
  # @!attribute [rw] semantic_chunking_group_size
  #   @return [::Boolean]
  #     Optional. The number of tokens to group together when evaluating
  #     semantic similarity. THIS FIELD IS NOT YET USED.
  # @!attribute [rw] breakpoint_percentile_threshold
  #   @return [::Integer]
  #     Optional. The percentile of cosine dissimilarity that must be exceeded
  #     between a group of tokens and the next. The smaller this number is, the
  #     more chunks will be generated. THIS FIELD IS NOT YET USED.
  class ChunkingConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end