Class: Google::Cloud::DocumentAI::V1beta3::ReviewDocumentOperationMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb

Overview

The long-running operation metadata for the ReviewDocument method.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#common_metadata::Google::Cloud::DocumentAI::V1beta3::CommonOperationMetadata

Returns The basic metadata of the long-running operation.

Returns:



1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1054

class ReviewDocumentOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the long-running operation.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Operation is still running.
    RUNNING = 1

    # Operation is being cancelled.
    CANCELLING = 2

    # Operation succeeded.
    SUCCEEDED = 3

    # Operation failed.
    FAILED = 4

    # Operation is cancelled.
    CANCELLED = 5
  end
end

#create_time::Google::Protobuf::Timestamp

Returns The creation time of the operation.

Returns:



1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1054

class ReviewDocumentOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the long-running operation.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Operation is still running.
    RUNNING = 1

    # Operation is being cancelled.
    CANCELLING = 2

    # Operation succeeded.
    SUCCEEDED = 3

    # Operation failed.
    FAILED = 4

    # Operation is cancelled.
    CANCELLED = 5
  end
end

#question_id::String

Returns The Crowd Compute question ID.

Returns:

  • (::String)

    The Crowd Compute question ID.



1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1054

class ReviewDocumentOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the long-running operation.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Operation is still running.
    RUNNING = 1

    # Operation is being cancelled.
    CANCELLING = 2

    # Operation succeeded.
    SUCCEEDED = 3

    # Operation failed.
    FAILED = 4

    # Operation is cancelled.
    CANCELLED = 5
  end
end

#state::Google::Cloud::DocumentAI::V1beta3::ReviewDocumentOperationMetadata::State

Returns Used only when Operation.done is false.

Returns:



1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1054

class ReviewDocumentOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the long-running operation.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Operation is still running.
    RUNNING = 1

    # Operation is being cancelled.
    CANCELLING = 2

    # Operation succeeded.
    SUCCEEDED = 3

    # Operation failed.
    FAILED = 4

    # Operation is cancelled.
    CANCELLED = 5
  end
end

#state_message::String

Returns A message providing more details about the current state of processing. For example, the error message if the operation is failed.

Returns:

  • (::String)

    A message providing more details about the current state of processing. For example, the error message if the operation is failed.



1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1054

class ReviewDocumentOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the long-running operation.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Operation is still running.
    RUNNING = 1

    # Operation is being cancelled.
    CANCELLING = 2

    # Operation succeeded.
    SUCCEEDED = 3

    # Operation failed.
    FAILED = 4

    # Operation is cancelled.
    CANCELLED = 5
  end
end

#update_time::Google::Protobuf::Timestamp

Returns The last update time of the operation.

Returns:



1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1054

class ReviewDocumentOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # State of the long-running operation.
  module State
    # Unspecified state.
    STATE_UNSPECIFIED = 0

    # Operation is still running.
    RUNNING = 1

    # Operation is being cancelled.
    CANCELLING = 2

    # Operation succeeded.
    SUCCEEDED = 3

    # Operation failed.
    FAILED = 4

    # Operation is cancelled.
    CANCELLED = 5
  end
end