Class: Google::Cloud::DocumentAI::V1beta3::ReviewDocumentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DocumentAI::V1beta3::ReviewDocumentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb
Overview
Request message for the ReviewDocument method.
Defined Under Namespace
Modules: Priority
Instance Attribute Summary collapse
-
#document ⇒ ::Google::Cloud::DocumentAI::V1beta3::Document
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#document_schema ⇒ ::Google::Cloud::DocumentAI::V1beta3::DocumentSchema
The document schema of the human review task.
-
#enable_schema_validation ⇒ ::Boolean
Whether the validation should be performed on the ad-hoc review request.
-
#human_review_config ⇒ ::String
Required.
-
#inline_document ⇒ ::Google::Cloud::DocumentAI::V1beta3::Document
An inline document proto.
-
#priority ⇒ ::Google::Cloud::DocumentAI::V1beta3::ReviewDocumentRequest::Priority
The priority of the human review task.
Instance Attribute Details
#document ⇒ ::Google::Cloud::DocumentAI::V1beta3::Document
This field is deprecated and may be removed in the next major version update.
Returns The document that needs human review.
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 987 class ReviewDocumentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The priority level of the human review task. module Priority # The default priority level. DEFAULT = 0 # The urgent priority level. The labeling manager should allocate labeler # resource to the urgent task queue to respect this priority level. URGENT = 1 end end |
#document_schema ⇒ ::Google::Cloud::DocumentAI::V1beta3::DocumentSchema
Returns The document schema of the human review task.
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 987 class ReviewDocumentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The priority level of the human review task. module Priority # The default priority level. DEFAULT = 0 # The urgent priority level. The labeling manager should allocate labeler # resource to the urgent task queue to respect this priority level. URGENT = 1 end end |
#enable_schema_validation ⇒ ::Boolean
Returns Whether the validation should be performed on the ad-hoc review request.
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 987 class ReviewDocumentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The priority level of the human review task. module Priority # The default priority level. DEFAULT = 0 # The urgent priority level. The labeling manager should allocate labeler # resource to the urgent task queue to respect this priority level. URGENT = 1 end end |
#human_review_config ⇒ ::String
Returns Required. The resource name of the [HumanReviewConfig][google.cloud.documentai.v1beta3.HumanReviewConfig] that the document will be reviewed with.
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 987 class ReviewDocumentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The priority level of the human review task. module Priority # The default priority level. DEFAULT = 0 # The urgent priority level. The labeling manager should allocate labeler # resource to the urgent task queue to respect this priority level. URGENT = 1 end end |
#inline_document ⇒ ::Google::Cloud::DocumentAI::V1beta3::Document
Returns An inline document proto.
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 987 class ReviewDocumentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The priority level of the human review task. module Priority # The default priority level. DEFAULT = 0 # The urgent priority level. The labeling manager should allocate labeler # resource to the urgent task queue to respect this priority level. URGENT = 1 end end |
#priority ⇒ ::Google::Cloud::DocumentAI::V1beta3::ReviewDocumentRequest::Priority
Returns The priority of the human review task.
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 987 class ReviewDocumentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The priority level of the human review task. module Priority # The default priority level. DEFAULT = 0 # The urgent priority level. The labeling manager should allocate labeler # resource to the urgent task queue to respect this priority level. URGENT = 1 end end |