Class: Google::Cloud::DocumentAI::V1beta3::ReviewDocumentResponse
- Inherits:
-
Object
- Object
- Google::Cloud::DocumentAI::V1beta3::ReviewDocumentResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb
Overview
Response message for the ReviewDocument method.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#gcs_destination ⇒ ::String
The Cloud Storage uri for the human reviewed document if the review is succeeded.
-
#rejection_reason ⇒ ::String
The reason why the review is rejected by reviewer.
-
#state ⇒ ::Google::Cloud::DocumentAI::V1beta3::ReviewDocumentResponse::State
The state of the review operation.
Instance Attribute Details
#gcs_destination ⇒ ::String
Returns The Cloud Storage uri for the human reviewed document if the review is succeeded.
1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1015 class ReviewDocumentResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of the review operation. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The review operation is rejected by the reviewer. REJECTED = 1 # The review operation is succeeded. SUCCEEDED = 2 end end |
#rejection_reason ⇒ ::String
Returns The reason why the review is rejected by reviewer.
1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1015 class ReviewDocumentResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of the review operation. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The review operation is rejected by the reviewer. REJECTED = 1 # The review operation is succeeded. SUCCEEDED = 2 end end |
#state ⇒ ::Google::Cloud::DocumentAI::V1beta3::ReviewDocumentResponse::State
Returns The state of the review operation.
1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1015 class ReviewDocumentResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of the review operation. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The review operation is rejected by the reviewer. REJECTED = 1 # The review operation is succeeded. SUCCEEDED = 2 end end |