Class: Google::Cloud::DocumentAI::V1beta3::RevisionRef

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/documentai/v1beta3/document.rb

Overview

The revision reference specifies which revision on the document to read.

Defined Under Namespace

Modules: RevisionCase

Instance Attribute Summary collapse

Instance Attribute Details

#latest_processor_version::String

Returns Reads the revision generated by the processor version. The format takes the full resource name of processor version. projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}

Note: The following fields are mutually exclusive: latest_processor_version, revision_case, revision_id. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Reads the revision generated by the processor version. The format takes the full resource name of processor version. projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}

    Note: The following fields are mutually exclusive: latest_processor_version, revision_case, revision_id. If a field in that set is populated, all other fields in the set will automatically be cleared.



1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1552

class RevisionRef
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Some predefined revision cases.
  module RevisionCase
    # Unspecified case, fall back to read the `LATEST_HUMAN_REVIEW`.
    REVISION_CASE_UNSPECIFIED = 0

    # The latest revision made by a human.
    LATEST_HUMAN_REVIEW = 1

    # The latest revision based on timestamp.
    LATEST_TIMESTAMP = 2

    # The first (OCR) revision.
    BASE_OCR_REVISION = 3
  end
end

#revision_case::Google::Cloud::DocumentAI::V1beta3::RevisionRef::RevisionCase

Returns Reads the revision by the predefined case.

Note: The following fields are mutually exclusive: revision_case, revision_id, latest_processor_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DocumentAI::V1beta3::RevisionRef::RevisionCase)

    Reads the revision by the predefined case.

    Note: The following fields are mutually exclusive: revision_case, revision_id, latest_processor_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1552

class RevisionRef
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Some predefined revision cases.
  module RevisionCase
    # Unspecified case, fall back to read the `LATEST_HUMAN_REVIEW`.
    REVISION_CASE_UNSPECIFIED = 0

    # The latest revision made by a human.
    LATEST_HUMAN_REVIEW = 1

    # The latest revision based on timestamp.
    LATEST_TIMESTAMP = 2

    # The first (OCR) revision.
    BASE_OCR_REVISION = 3
  end
end

#revision_id::String

Returns Reads the revision given by the id.

Note: The following fields are mutually exclusive: revision_id, revision_case, latest_processor_version. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Reads the revision given by the id.

    Note: The following fields are mutually exclusive: revision_id, revision_case, latest_processor_version. If a field in that set is populated, all other fields in the set will automatically be cleared.



1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1552

class RevisionRef
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Some predefined revision cases.
  module RevisionCase
    # Unspecified case, fall back to read the `LATEST_HUMAN_REVIEW`.
    REVISION_CASE_UNSPECIFIED = 0

    # The latest revision made by a human.
    LATEST_HUMAN_REVIEW = 1

    # The latest revision based on timestamp.
    LATEST_TIMESTAMP = 2

    # The first (OCR) revision.
    BASE_OCR_REVISION = 3
  end
end