Class: Google::Cloud::DocumentAI::V1beta3::TrainProcessorVersionMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::DocumentAI::V1beta3::TrainProcessorVersionMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb
Overview
The metadata that represents a processor version being created.
Defined Under Namespace
Classes: DatasetValidation
Instance Attribute Summary collapse
-
#common_metadata ⇒ ::Google::Cloud::DocumentAI::V1beta3::CommonOperationMetadata
The basic metadata of the long-running operation.
-
#test_dataset_validation ⇒ ::Google::Cloud::DocumentAI::V1beta3::TrainProcessorVersionMetadata::DatasetValidation
The test dataset validation information.
-
#training_dataset_validation ⇒ ::Google::Cloud::DocumentAI::V1beta3::TrainProcessorVersionMetadata::DatasetValidation
The training dataset validation information.
Instance Attribute Details
#common_metadata ⇒ ::Google::Cloud::DocumentAI::V1beta3::CommonOperationMetadata
Returns The basic metadata of the long-running operation.
935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 935 class TrainProcessorVersionMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The dataset validation information. # This includes any and all errors with documents and the dataset. # @!attribute [rw] document_error_count # @return [::Integer] # The total number of document errors. # @!attribute [rw] dataset_error_count # @return [::Integer] # The total number of dataset errors. # @!attribute [rw] document_errors # @return [::Array<::Google::Rpc::Status>] # Error information pertaining to specific documents. A maximum of 10 # document errors will be returned. # Any document with errors will not be used throughout training. # @!attribute [rw] dataset_errors # @return [::Array<::Google::Rpc::Status>] # Error information for the dataset as a whole. A maximum of 10 dataset # errors will be returned. # A single dataset error is terminal for training. class DatasetValidation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#test_dataset_validation ⇒ ::Google::Cloud::DocumentAI::V1beta3::TrainProcessorVersionMetadata::DatasetValidation
Returns The test dataset validation information.
935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 935 class TrainProcessorVersionMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The dataset validation information. # This includes any and all errors with documents and the dataset. # @!attribute [rw] document_error_count # @return [::Integer] # The total number of document errors. # @!attribute [rw] dataset_error_count # @return [::Integer] # The total number of dataset errors. # @!attribute [rw] document_errors # @return [::Array<::Google::Rpc::Status>] # Error information pertaining to specific documents. A maximum of 10 # document errors will be returned. # Any document with errors will not be used throughout training. # @!attribute [rw] dataset_errors # @return [::Array<::Google::Rpc::Status>] # Error information for the dataset as a whole. A maximum of 10 dataset # errors will be returned. # A single dataset error is terminal for training. class DatasetValidation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#training_dataset_validation ⇒ ::Google::Cloud::DocumentAI::V1beta3::TrainProcessorVersionMetadata::DatasetValidation
Returns The training dataset validation information.
935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 935 class TrainProcessorVersionMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The dataset validation information. # This includes any and all errors with documents and the dataset. # @!attribute [rw] document_error_count # @return [::Integer] # The total number of document errors. # @!attribute [rw] dataset_error_count # @return [::Integer] # The total number of dataset errors. # @!attribute [rw] document_errors # @return [::Array<::Google::Rpc::Status>] # Error information pertaining to specific documents. A maximum of 10 # document errors will be returned. # Any document with errors will not be used throughout training. # @!attribute [rw] dataset_errors # @return [::Array<::Google::Rpc::Status>] # Error information for the dataset as a whole. A maximum of 10 dataset # errors will be returned. # A single dataset error is terminal for training. class DatasetValidation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |