Class: Google::Cloud::DocumentAI::V1beta3::TrainProcessorVersionRequest::FoundationModelTuningOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb

Overview

Options to control foundation model tuning of the processor.

Instance Attribute Summary collapse

Instance Attribute Details

#learning_rate_multiplier::Float

Returns Optional. The multiplier to apply to the recommended learning rate. Valid values are between 0.1 and 10. If not provided, recommended learning rate will be used.

Returns:

  • (::Float)

    Optional. The multiplier to apply to the recommended learning rate. Valid values are between 0.1 and 10. If not provided, recommended learning rate will be used.



909
910
911
912
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 909

class FoundationModelTuningOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#previous_fine_tuned_processor_version_name::String

Returns Optional. Resource name of a previously fine tuned version id to copy the overwritten configs from. The base_processor_version should be newer than the base processor version used to fine tune this provided processor version. Format: projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}.

Returns:

  • (::String)

    Optional. Resource name of a previously fine tuned version id to copy the overwritten configs from. The base_processor_version should be newer than the base processor version used to fine tune this provided processor version. Format: projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}.



909
910
911
912
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 909

class FoundationModelTuningOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#train_steps::Integer

Returns Optional. The number of steps to run for model tuning. Valid values are between 1 and 400. If not provided, recommended steps will be used.

Returns:

  • (::Integer)

    Optional. The number of steps to run for model tuning. Valid values are between 1 and 400. If not provided, recommended steps will be used.



909
910
911
912
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 909

class FoundationModelTuningOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end