Class: Google::Cloud::DocumentAI::V1beta3::Document::EntityValidationOutput::ValidationResult
- Inherits:
-
Object
- Object
- Google::Cloud::DocumentAI::V1beta3::Document::EntityValidationOutput::ValidationResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/documentai/v1beta3/document.rb
Overview
Validation result for a single validation rule.
Defined Under Namespace
Modules: ValidationResultType
Instance Attribute Summary collapse
-
#rule_description ⇒ ::String
The description of the validation rule.
-
#rule_name ⇒ ::String
The display name of the validation rule.
-
#validation_details ⇒ ::String
The detailed information of the running the validation process using the entity from the document based on the validation rule.
-
#validation_result_type ⇒ ::Google::Cloud::DocumentAI::V1beta3::Document::EntityValidationOutput::ValidationResult::ValidationResultType
The result of the validation rule.
Instance Attribute Details
#rule_description ⇒ ::String
Returns The description of the validation rule.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1491 class ValidationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of the validation rule. module ValidationResultType # The validation result type is unspecified. VALIDATION_RESULT_TYPE_UNSPECIFIED = 0 # The validation is valid. VALIDATION_RESULT_TYPE_VALID = 1 # The validation is invalid. VALIDATION_RESULT_TYPE_INVALID = 2 # The validation is skipped. VALIDATION_RESULT_TYPE_SKIPPED = 3 # The validation is not applicable. VALIDATION_RESULT_TYPE_NOT_APPLICABLE = 4 end end |
#rule_name ⇒ ::String
Returns The display name of the validation rule.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1491 class ValidationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of the validation rule. module ValidationResultType # The validation result type is unspecified. VALIDATION_RESULT_TYPE_UNSPECIFIED = 0 # The validation is valid. VALIDATION_RESULT_TYPE_VALID = 1 # The validation is invalid. VALIDATION_RESULT_TYPE_INVALID = 2 # The validation is skipped. VALIDATION_RESULT_TYPE_SKIPPED = 3 # The validation is not applicable. VALIDATION_RESULT_TYPE_NOT_APPLICABLE = 4 end end |
#validation_details ⇒ ::String
Returns The detailed information of the running the validation process using the entity from the document based on the validation rule.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1491 class ValidationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of the validation rule. module ValidationResultType # The validation result type is unspecified. VALIDATION_RESULT_TYPE_UNSPECIFIED = 0 # The validation is valid. VALIDATION_RESULT_TYPE_VALID = 1 # The validation is invalid. VALIDATION_RESULT_TYPE_INVALID = 2 # The validation is skipped. VALIDATION_RESULT_TYPE_SKIPPED = 3 # The validation is not applicable. VALIDATION_RESULT_TYPE_NOT_APPLICABLE = 4 end end |
#validation_result_type ⇒ ::Google::Cloud::DocumentAI::V1beta3::Document::EntityValidationOutput::ValidationResult::ValidationResultType
Returns The result of the validation rule.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document.rb', line 1491 class ValidationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The result of the validation rule. module ValidationResultType # The validation result type is unspecified. VALIDATION_RESULT_TYPE_UNSPECIFIED = 0 # The validation is valid. VALIDATION_RESULT_TYPE_VALID = 1 # The validation is invalid. VALIDATION_RESULT_TYPE_INVALID = 2 # The validation is skipped. VALIDATION_RESULT_TYPE_SKIPPED = 3 # The validation is not applicable. VALIDATION_RESULT_TYPE_NOT_APPLICABLE = 4 end end |