Class: Google::Cloud::DocumentAI::V1beta3::ImportProcessorVersionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DocumentAI::V1beta3::ImportProcessorVersionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb
Overview
The request message for the ImportProcessorVersion method.
The Document AI Service Agent of the destination project must have Document AI Editor role on the source project.
The destination project is specified as part of the parent field. The source project is specified as part of the source or external_processor_version_source field.
Defined Under Namespace
Classes: ExternalProcessorVersionSource
Instance Attribute Summary collapse
-
#external_processor_version_source ⇒ ::Google::Cloud::DocumentAI::V1beta3::ImportProcessorVersionRequest::ExternalProcessorVersionSource
The source processor version to import from.
-
#parent ⇒ ::String
Required.
-
#processor_version_source ⇒ ::String
The source processor version to import from.
Instance Attribute Details
#external_processor_version_source ⇒ ::Google::Cloud::DocumentAI::V1beta3::ImportProcessorVersionRequest::ExternalProcessorVersionSource
Returns The source processor version to import from. It can be from a different environment and region than the destination processor.
Note: The following fields are mutually exclusive: external_processor_version_source, processor_version_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1200 class ImportProcessorVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The external source processor version. # @!attribute [rw] processor_version # @return [::String] # Required. The processor version name. Format: # `projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}` # @!attribute [rw] service_endpoint # @return [::String] # Optional. The Document AI service endpoint. For example, # 'https://us-documentai.googleapis.com' class ExternalProcessorVersionSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#parent ⇒ ::String
Returns Required. The destination processor name to create the processor version
in. Format:
projects/{project}/locations/{location}/processors/{processor}.
1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1200 class ImportProcessorVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The external source processor version. # @!attribute [rw] processor_version # @return [::String] # Required. The processor version name. Format: # `projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}` # @!attribute [rw] service_endpoint # @return [::String] # Optional. The Document AI service endpoint. For example, # 'https://us-documentai.googleapis.com' class ExternalProcessorVersionSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#processor_version_source ⇒ ::String
Returns The source processor version to import from. The source processor version and destination processor need to be in the same environment and region.
Note: The following fields are mutually exclusive: processor_version_source, external_processor_version_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'proto_docs/google/cloud/documentai/v1beta3/document_processor_service.rb', line 1200 class ImportProcessorVersionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The external source processor version. # @!attribute [rw] processor_version # @return [::String] # Required. The processor version name. Format: # `projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}` # @!attribute [rw] service_endpoint # @return [::String] # Optional. The Document AI service endpoint. For example, # 'https://us-documentai.googleapis.com' class ExternalProcessorVersionSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |